@@ -272,7 +272,7 @@ static void bot_bye (int idx, char * par) {
    char s[1024];
   
    context;
-   simple_sprintf(s,"%s %s", BOT_DISCONNECTED, dcc[idx].nick);
+   simple_sprintf(s,"%s %s. %s", BOT_DISCONNECTED, dcc[idx].nick, par);
    putlog(LOG_BOTS, "*", "%s", s);
    chatout("*** %s\n", s);
    botnet_send_unlinked (idx, dcc[idx].nick, s);
@@ -592,9 +592,9 @@ static void bot_nlinked (int idx, char * par) {
       dprintf(idx, "error Loop (%s)\n", newbot);
    } 
    if (!s[0]) {
-      for (p = newbot; *p; p++)
-	 if ((*p < 32) || (*p == 127))
-	    bogus = 1;
+      for (p = newbot; *p; p++) 
+	if ((*p < 32) || (*p == 127) || ((p - newbot) >= HANDLEN))
+	  bogus = 1;
       i = nextbot(next);
       if (i != idx)
 	 bogus = 1;
