@@ -697,12 +697,15 @@ int add_note (char * to, char * from, char * msg, int idx, int echo)
    if (p != NULL) {		/* cross-bot note */
       char x[20];
       *p = 0;
-      strcpy(x,to);
+      strncpy(x,to,20);
+      x[20] = 0;
       *p = '@';
       p++;
       if (strcasecmp(p, botnetnick) == 0)	/* to me?? */
 	return add_note(x, from, msg, idx, echo);	/* start over, dimwit. */
       if (strcasecmp(from, botnetnick)) {
+	 if (strlen(from) > 40)
+	   from[40] = 0;
 	 if (strchr(from,'@')) {
 	    strcpy(botf, from);
 	 } else
@@ -804,8 +807,8 @@ int add_note (char * to, char * from, char * msg, int idx, int echo)
    set_tcl_vars();
    if (Tcl_VarEval(interp,"storenote"," $_from $_to $_data $_idx",NULL) == TCL_OK) {
       if (interp->result && interp->result[0]) {
-	 strncpy(to, interp->result,120);
-	 to[120] = 0;
+	 strncpy(to, interp->result,NOTENAMELEN);
+	 to[NOTENAMELEN] = 0;
 	 status = NOTE_FWD;
       }
       if (status == NOTE_AWAY) {
