@@ -52,6 +52,7 @@ struct chanset_t *chanset = NULL;
 char admin[121] = "";
 /* primary botname */
 char origbotname[NICKLEN+1];
+char botname[NICKLEN+1];
 
 /* remove space characters from beginning and end of string */
 /* (more efficent by Fred1) */
@@ -274,7 +275,8 @@ void tell_verbose_status (int idx, int showchan)
    dprintf(idx, "%s %s  (%s)  %s  %s %4.1f%%\n", MISC_ONLINEFOR,
 			s, s1, s2, MISC_CACHEHIT,
        100.0 * ((float) cache_hit) / ((float) (cache_hit + cache_miss)));
-   if ((interp) && (Tcl_Eval(interp,"info library") == TCL_OK)) 
+   strcpy(s, "info library");
+   if ((interp) && (Tcl_Eval(interp, s) == TCL_OK)) 
       dprintf(idx, "%s %s\n",MISC_TCLLIBVER, interp->result);	      
 }
 
@@ -374,7 +376,7 @@ void chanprog()
       /* like rm -rf /etc :) */
       printf("\n\n%s\n", MISC_ROOTWARN);
    }
-   if (!readuserfile(userfile, &userlist,0)) {
+   if (!readuserfile(userfile, &userlist)) {
       if (!make_userfile)
 	fatal(MISC_NOUSERFILE, 0);
       printf("\n\n%s\n", MISC_NOUSERFILE2);
@@ -427,7 +429,7 @@ void reload()
    clear_userlist(userlist);
    noshare = 0;
    userlist = NULL;
-   if (!readuserfile(userfile, &userlist,0))
+   if (!readuserfile(userfile, &userlist))
       fatal(MISC_MISSINGUSERF, 0);
    context;
    reaffirm_owners();
