@@ -617,6 +617,9 @@ static void cmd_console (struct userrec * u, int idx, char * par) {
       strncpy(dcc[dest].u.chat->con_chan, nick, 80);
       dcc[dest].u.chat->con_chan[80] = 0;
       nick[0] = 0;
+      if ((dest == idx) && !glob_master(fr) && !chan_master(fr)) 
+	/* consoling to another channel for self */
+	dcc[dest].u.chat->con_flags &= ~(LOG_MISC | LOG_CMDS | LOG_WALL);
    }
    if (!nick[0])
       nick = newsplit(&par);
@@ -643,12 +646,10 @@ static void cmd_console (struct userrec * u, int idx, char * par) {
 			 LOG_LEV3 | LOG_LEV4 | LOG_LEV5 | LOG_LEV6 | LOG_LEV7 |
 			 LOG_LEV8 | LOG_WALL | LOG_DEBUG);
 	    }
-	    if (!glob_owner(fr) && pls) {
-	       md &= ~(LOG_RAW|LOG_SRVOUT|LOG_BOTNET|LOG_BOTSHARE);
-	    }
-	    if (!glob_botmast(fr) && pls) {
-	       md &= ~LOG_BOTS;
-	    }
+	    if (!glob_owner(fr) && pls) 
+	      md &= ~(LOG_RAW|LOG_SRVOUT|LOG_BOTNET|LOG_BOTSHARE);
+	    if (!glob_botmast(fr) && pls) 
+	      md &= ~LOG_BOTS;
 	    if (pls)
 	      dcc[dest].u.chat->con_flags |= md;
 	    else
@@ -1982,38 +1983,38 @@ static void cmd_module (struct userrec * u, int idx, char * par)
    do_module_report(idx,2,par[0]?par:NULL);
 }
 
-static void cmd_loadmodule (struct userrec * u, int idx, char * par)
+static void cmd_loadmod (struct userrec * u, int idx, char * par)
 {
    const char *p;
 
    context;
    if (!par[0]) {
-      dprintf(idx, "%s: loadmodule <module>\n", USAGE);
+      dprintf(idx, "%s: loadmod <module>\n", USAGE);
    } else {
       p = module_load(par);
       if (p)
 	 dprintf(idx, "%s: %s %s\n", par, MOD_LOADERROR, p);
       else {
-	 putlog(LOG_CMDS, "*", "#%s# loadmodule %s", dcc[idx].nick, par);
+	 putlog(LOG_CMDS, "*", "#%s# loadmod %s", dcc[idx].nick, par);
 	 dprintf(idx, "%s %s\n", MOD_LOADED, par);
       }
    }
    context;
 }
 
-static void cmd_unloadmodule (struct userrec * u, int idx, char * par)
+static void cmd_unloadmod (struct userrec * u, int idx, char * par)
 {
    char *p;
 
    context;
    if (!par[0]) {
-      dprintf(idx, "%s: unloadmodule <module>\n", USAGE);
+      dprintf(idx, "%s: unloadmod <module>\n", USAGE);
    } else {
       p = module_unload(par,dcc[idx].nick);
       if (p)
 	 dprintf(idx, "%s %s: %s\n", MOD_UNLOADERROR, par, p);
       else {
-	 putlog(LOG_CMDS, "*", "#%s# unloadmodule %s", dcc[idx].nick, par);
+	 putlog(LOG_CMDS, "*", "#%s# unloadmod %s", dcc[idx].nick, par);
 	 dprintf(idx, "%s %s\n", MOD_UNLOADED, par);
       }
    }
@@ -2022,31 +2023,52 @@ static void cmd_unloadmodule (struct userrec * u, int idx, char * par)
 static void cmd_pls_ignore (struct userrec * u, int idx, char * par)
 {
    char * who;
+   char s[UHOSTLEN + 1];
+
    if (!par[0]) {
       dprintf(idx, "Usage: +ignore <hostmask> [comment]\n");
       return;
    }
    who = newsplit(&par);
-   if (strlen(par) > 65)
-     par[65] =0 ;
-   if (match_ignore(who)) {
+   remove_gunk(who);
+   if (!par[0])
+     par = "requested";
+   else if (strlen(par) > 65)
+     par[65] = 0;
+   if (strlen(who) > UHOSTLEN - 4)
+     who[UHOSTLEN-4] = 0;
+   /* fix missing ! or @ BEFORE continuing - sounds familiar */
+   if (!strchr(who, '!')) {
+      if (!strchr(who, '@'))
+	simple_sprintf(s, "%s!*@*", who);
+      else
+	simple_sprintf(s, "*!%s", who);
+   } else if (!strchr(who, '@'))
+	simple_sprintf(s, "%s@*", who);
+   else
+      strcpy(s, who);
+
+   if (match_ignore(s)) {
       dprintf(idx, "That already matches an existing ignore.\n");
       return;
    }
-   dprintf(idx, "Now ignoring: %s (%s)\n", who, par);
-   addignore(who, dcc[idx].nick, par, 0L);
-   putlog(LOG_CMDS, "*", "#%s# +ignore %s %s", dcc[idx].nick, who, par);
+   dprintf(idx, "Now ignoring: %s (%s)\n", s, par);
+   addignore(s, dcc[idx].nick, par, 0L);
+   putlog(LOG_CMDS, "*", "#%s# +ignore %s %s", dcc[idx].nick, s, par);
 }
 
-static void cmd_mns_ignore (struct userrec * u, int idx, char * par)
-{
+static void cmd_mns_ignore (struct userrec * u, int idx, char * par) {
+   char buf[UHOSTLEN+1];
+   
    if (!par[0]) {
-      dprintf(idx, "Usage: -ignore <hostmask>\n");
+      dprintf(idx, "Usage: -ignore <hostmask | ignore #>\n");
       return;
    }
-   if (delignore(par)) {
-      putlog(LOG_CMDS, "*", "#%s# -ignore %s", dcc[idx].nick, par);
-      dprintf(idx, "No longer ignoring: %s\n", par);
+   strncpy(buf, par, UHOSTLEN);
+   buf[UHOSTLEN] = 0;
+   if (delignore(buf)) {
+      putlog(LOG_CMDS, "*", "#%s# -ignore %s", dcc[idx].nick, buf);
+      dprintf(idx, "No longer ignoring: %s\n", buf);
    } else
       dprintf(idx, "Can't find that ignore.\n");
 }
@@ -2259,7 +2281,7 @@ cmd_t C_dcc[63]={
   { "help", "", (Function)cmd_help, NULL },
   { "ignores", "m", (Function)cmd_ignores, NULL },
   { "link", "t", (Function)cmd_link, NULL },
-  { "loadmod", "n", (Function)cmd_loadmodule, NULL },
+  { "loadmod", "n", (Function)cmd_loadmod, NULL },
   { "match", "to|o", (Function)cmd_match, NULL },
   { "me", "", (Function)cmd_me, NULL },
   { "module", "m", (Function)cmd_module, NULL },
@@ -2284,7 +2306,7 @@ cmd_t C_dcc[63]={
   { "tcl", "n", (Function)cmd_tcl, NULL },
   { "trace", "", (Function)cmd_trace, NULL },
   { "unlink", "t", (Function)cmd_unlink, NULL },
-  { "unloadmod", "n", (Function)cmd_unloadmodule, NULL },
+  { "unloadmod", "n", (Function)cmd_unloadmod, NULL },
   { "vbottree", "t", (Function)cmd_vbottree, NULL },
   { "who", "", (Function)cmd_who, NULL },
   { "whois", "to|o", (Function)cmd_whois, NULL },
