@@ -77,8 +77,8 @@ extern tcl_timer_t *timer, *utimer;
    modified versions of this bot.
 
  */
-char egg_version[1024] = "1.3.13";
-int egg_numver = 1031300;
+char egg_version[1024] = "1.3.19";
+int egg_numver = 1031900;
 
 /* person to send a note to for new users */
 char notify_new[121] = "";
@@ -196,9 +196,9 @@ void write_debug()
 	 dprintf(-x, "Debug (%s) written %s", ver, s);
 	 dprintf(-x, "Full Patch List: %s\n", egg_xtra);
 	 dprintf(-x, "Context: ");
-	 for (y = ((cx_ptr + 1) & 15); y != cx_ptr; y = ((y + 1) & 15)) {
-	    dprintf(-x, "%s/%d,\n         ", cx_file[y], cx_line[y]);
-	 }
+	 cx_ptr = cx_ptr & 15;
+	 for (y = ((cx_ptr + 1) & 15); y != cx_ptr; y = ((y + 1) & 15)) 
+	   dprintf(-x, "%s/%d,\n         ", cx_file[y], cx_line[y]);
 	 dprintf(-x, "%s/%d\n\n", cx_file[y], cx_line[y]);
 	 killsock(x);
 	 close(x);
@@ -219,16 +219,17 @@ void write_debug()
 #ifdef STATIC
 	dprintf(-x, "STATICALLY LINKED\n");
 #endif
-      if (interp && (Tcl_Eval(interp,"info library") == TCL_OK)) 
+      strcpy(s, "info library");
+      if (interp && (Tcl_Eval(interp, s) == TCL_OK)) 
 	dprintf(-x, "Using tcl library: %s (header version %s)\n",
 		interp->result, TCL_VERSION);
       dprintf(-x, "Compile flags: %s\n", CCFLAGS);
       dprintf(-x, "Link flags   : %s\n", LDFLAGS);
       dprintf(-x, "Strip flags  : %s\n", STRIPFLAGS);
       dprintf(-x, "Context: ");
-      for (y = ((cx_ptr + 1) & 15); y != cx_ptr; y = ((y + 1) & 15)) {
-	 dprintf(-x, "%s/%d,\n         ", cx_file[y], cx_line[y]);
-      }
+      cx_ptr = cx_ptr & 15;
+      for (y = ((cx_ptr + 1) & 15); y != cx_ptr; y = ((y + 1) & 15)) 
+	dprintf(-x, "%s/%d,\n         ", cx_file[y], cx_line[y]);
       dprintf(-x, "%s/%d\n\n", cx_file[cx_ptr], cx_line[cx_ptr]);
       tell_dcc(-x);
       dprintf(-x, "\n");
@@ -629,7 +630,24 @@ int main (int argc, char ** argv)
       if (xx == -1)
 	 fatal("CANNOT FORK PROCESS.", 0);
       if (xx != 0) {
-	 printf("Launched into the background  (pid: %d)\n\n", xx);
+         FILE *fp;
+         /* need to attempt to write pid now, not later */
+         unlink(pid_file);
+         fp = fopen(pid_file, "w");
+         if (fp != NULL) {
+            fprintf(fp, "%u\n", xx);
+            if (fflush(fp)) {
+               /* kill bot incase a botchk is run from crond */
+               printf("* Warning!  Could not write %s file!\n", pid_file);
+               printf("  Try freeing some disk space\n");
+               fclose(fp);
+               unlink(pid_file);
+               exit(1);
+            }
+            fclose(fp);
+         } else
+            printf("* Warning!  Could not write %s file!\n", pid_file);
+         printf("Launched into the background  (pid: %d)\n\n", xx);
 #if HAVE_SETPGID
 	 setpgid(xx, xx);
 #endif
@@ -638,13 +656,19 @@ int main (int argc, char ** argv)
    }
    use_stderr = 0;		/* stop writing to stderr now */
    xx = getpid();
-   if (xx != 0) {
+   if ((xx != 0) && (!backgrd)) {
       FILE *fp;
       /* write pid to file */
       unlink(pid_file);
       fp = fopen(pid_file, "w");
       if (fp != NULL) {
 	 fprintf(fp, "%u\n", xx);
+         if (fflush(fp)) {
+      /* let the bot live since this doesn't appear to be a botchk */
+            printf("* Warning!  Could not write %s file!\n", pid_file);
+            fclose(fp);
+            unlink(pid_file);
+         }
 	 fclose(fp);
       } else
 	 printf("* Warning!  Could not write %s file!\n", pid_file);
