@@ -186,61 +186,63 @@ char * newsplit ( char ** rest ) {
    or "abc!user@1.2.3.4" into "*!user@1.2.3.*"  */
 void maskhost (char * s, char * nw)
 {
-   char *p, *q, xx[150];
-   strcpy(xx, s);
-   p = strchr(s, '!');
-   if (p != NULL) {
-      /* copy username over, quoting '?' and '*' */
-      char *dest = xx, *src = p + 1;
-      while (*src) {
-	 if ((*src == '*') || (*src == '?'))
-	    *dest++ = '\\';
-	 *dest++ = *src++;
+   char *p, *q, *e, *f;
+   int i;
+
+   *nw++ = '*';
+   *nw++ = '!';
+   p = (q = strchr(s, '!')) ? q + 1 : s;
+   /* strip of any nick, if a username is found, use last 8 chars */
+   if ((q = strchr(p, '@'))) {
+         if ((q - p) > 10) {
+	          nw[0] = '*';
+	          p = q - 8;
+	          i = 1;
+	       } else
+           i = 0;
+         while (*p != '@')
+           nw[i++] = *p++;
+         nw[i++] = '@';
+         q++;
+      } else {
+            nw[0] = '*';
+            nw[1] = '@';
+            i = 2;
+            q = s;
       }
-      *dest = 0;
-      if (strlen(dest) > 10) {
-	 /* truncate */
-	 p = strchr(s, '@');
-	 if (p != NULL) {
-	    if (*(dest + 8) == '\\') {
-	       *(dest + 8) = '*';
-	       strcpy(dest + 9, p);
-	    } else {
-	       *(dest + 9) = '*';
-	       strcpy(dest + 10, p);
-	    }
-	 }
+   /* now q points to the hostname, i point to where to put the mask */
+   if (!(p = strchr(q, '.')) || !(e = strchr(p + 1, '.')))
+     /* TLD or 2 part host */
+     strcpy(nw + i, q);
+   else {
+      for (f = e; *f; f++);
+      f--;
+      if ((*f >= '0') && (*f <= '9')) {  /* numeric IP address */
+	 while (*f != '.')
+	   f--;
+	 strncpy(nw + i, q, f - q);
+	 i += (f - q);
+	 strcpy(nw + i, ".*");
+      } else { /* normal host >= 3 parts */
+	 /* ok, people whined at me...how about this? ..
+	  *    a.b.c  -> *.b.c
+	  *    a.b.c.d ->  *.b.c.d if tld is a country (2 chars)
+	  *             OR   *.c.d if tld is com/edu/etc (3 chars)
+	  *    a.b.c.d.e -> *.c.d.e   etc
+	  */
+	 char * x = strchr(e + 1, '.');
+	 
+	 if (!x) 
+	   x = p;
+	 else if (strchr(x + 1, '.'))
+	   x = e;
+	 else if (strlen(x) == 3)
+	   x = p;
+	 else 
+	   x = e;
+	 sprintf(nw + i, "*%s", x);
       }
    }
-   p = strchr(xx, '@');
-   if (p != NULL) {
-      q = strchr(p, '.');
-      if (q == NULL) {
-	 /* form xx@yy -> very bizarre */
-	 sprintf(nw, "*!%s", xx);
-	 return;
-      }
-      if (strchr(q + 1, '.') == NULL) {
-	 /* form xx@yy.com -> don't truncate */
-	 sprintf(nw, "*!%s", xx);
-	 return;
-      }
-      if ((xx[strlen(xx) - 1] >= '0') && (xx[strlen(xx) - 1] <= '9')) {
-	 /* ip number -> xx@#.#.#.* */
-	 q = strrchr(p, '.');
-	 if (q != NULL)
-	    strcpy(q, ".*");
-	 sprintf(nw, "*!%s", xx);
-	 return;
-      }
-      /* form xx@yy.zz.etc.edu or whatever -> xx@*.zz.etc.edu */
-      if (q != NULL) {
-	 *(p + 1) = '*';
-	 strcpy(p + 2, q);
-      }
-      sprintf(nw, "*!%s", xx);
-   } else
-      strcpy(nw, "*");
 }
 
 /* copy a file from one place to another (possibly erasing old copy) */
@@ -1059,3 +1061,17 @@ void show_motd (int idx)
    }
 }
 
+/* remove :'s from ignores and bans */
+void remove_gunk(char * par) {
+   char *q, *p;
+   char WBUF[strlen(par)+1];
+
+   for (p = par, q = WBUF ; *p ; p++, q++) {
+      if (*p == ':')
+	q--;
+      else
+	*q=*p;
+   }
+   *q=*p;
+   strcpy(par, WBUF);
+}
