@@ -31,8 +31,7 @@ void * channel_malloc (int size, char * file, int line) {
    return p;
 }
 
-static void set_mode_protect (struct chanset_t * chan, char * set)
-{
+static void set_mode_protect (struct chanset_t * chan, char * set) {
    int i, pos = 1;
    char *s, *s1;
    
@@ -105,8 +104,7 @@ static void set_mode_protect (struct chanset_t * chan, char * set)
    dprintf(DP_MODE,"MODE %s\n",chan->name);
 }
 
-static void get_mode_protect (struct chanset_t * chan, char * s)
-{
+static void get_mode_protect (struct chanset_t * chan, char * s) {
    char *p = s, s1[121];
    int ok = 0, i, tst;
    s1[0] = 0;
@@ -320,7 +318,10 @@ static void write_channels()
 	      channel_secret(chan) ? '+' : '-');
       fprintf(f, "%ccycle ", 
 	      channel_cycle(chan) ? '+' : '-');
-      if (fprintf(f, "%c\n", channel_static(chan) ? ' ' : '}') == EOF) {
+      fprintf(f, "%cseen ", 
+	      channel_seen(chan) ? '+' : '-');
+      fprintf(f, "%c\n", channel_static(chan) ? ' ' : '}');
+      if (fflush(f)) {
 	 putlog(LOG_MISC, "*", "ERROR writing channel file.");
 	 fclose(f);
 	 return;
@@ -412,8 +413,7 @@ static cmd_t my_chon[] = {
      { "*", "", (Function) channels_chon, "channels:chon" },
 };
    
-static void channels_report (int idx, int details)
-{
+static void channels_report (int idx, int details) {
    struct chanset_t * chan;
    int i;
    char s[1024], s2[100];
@@ -437,8 +437,8 @@ static void channels_report (int idx, int details)
 	   strcpy(s, MISC_LURKING);
 	 get_mode_protect(chan, s2);
 	 if (channel_active(chan))
-	   dprintf(idx, "    %-10s: %2d member%c, enforcing \"%s\"  (%s)\n", chan->name,
-		   chan->channel.members, chan->channel.members == 1 ? ' ' : 's', s2, s);
+	   dprintf(idx, "    %-10s: %2d member%s enforcing \"%s\" (%s)\n", chan->name,
+		   chan->channel.members, chan->channel.members == 1 ? "," : "s,", s2, s);
 	 else
 	   dprintf(idx, "    %-10s: (inactive), enforcing \"%s\"  (%s)\n",
 		   chan->name, s2, s);
