@@ -198,37 +198,40 @@ static struct user_entry_type USERENTRY_CONSOLE = {
 static int console_chon (char * handle, int idx) {
    struct console_info * i = get_user(&USERENTRY_CONSOLE,dcc[idx].user);
    
-   if (i) {
-      if (i->channel && i->channel[0]) 
-	strcpy(dcc[idx].u.chat->con_chan,i->channel);
-      if (i->conflags) 
-	dcc[idx].u.chat->con_flags = i->conflags;
-      if (i->stripflags)
-	dcc[idx].u.chat->strip_flags = i->stripflags;
-      if (i->echoflags)
-	dcc[idx].status |= STAT_ECHO;
-      else
-	dcc[idx].status &= ~STAT_ECHO;     
-      if (i->page) {
-	 dcc[idx].status |= STAT_PAGE;
-	 dcc[idx].u.chat->max_line = i->page;
-	 if (!dcc[idx].u.chat->line_count)
-	   dcc[idx].u.chat->current_lines = 0;
-      }
-      dcc[idx].u.chat->channel = i->conchan;
-   } else if (force_channel > -1)
-	dcc[idx].u.chat->channel = force_channel;
-   if (dcc[idx].u.chat->channel >= 0) 
-     botnet_send_join_idx(idx, -1);
-   if (info_party) {
-      char * p = get_user(&USERENTRY_INFO,dcc[idx].user);
-      if (p) {
-	 char x[1024];
-	 chanout_but(-1,dcc[idx].u.chat->channel,
-		     "*** [%s] %s\n", dcc[idx].nick, p);
-	 simple_sprintf(x,"[%s] %s",dcc[idx].nick,p);
-	 botnet_send_chan(-1,botnetnick,NULL,dcc[idx].u.chat->channel,
-			  x);
+   if (dcc[idx].type == &DCC_CHAT) {
+      if (i) {
+	 if (i->channel && i->channel[0]) 
+	   strcpy(dcc[idx].u.chat->con_chan,i->channel);
+	 if (i->conflags) 
+	   dcc[idx].u.chat->con_flags = i->conflags;
+	 if (i->stripflags)
+	   dcc[idx].u.chat->strip_flags = i->stripflags;
+	 if (i->echoflags)
+	   dcc[idx].status |= STAT_ECHO;
+	 else
+	   dcc[idx].status &= ~STAT_ECHO;     
+	 if (i->page) {
+	    dcc[idx].status |= STAT_PAGE;
+	    dcc[idx].u.chat->max_line = i->page;
+	    if (!dcc[idx].u.chat->line_count)
+	      dcc[idx].u.chat->current_lines = 0;
+	 }
+	 dcc[idx].u.chat->channel = i->conchan;
+      } else if (force_channel > -1)
+	   dcc[idx].u.chat->channel = force_channel;
+      if ((dcc[idx].u.chat->channel >= 0) && 
+	  (dcc[idx].u.chat->channel < GLOBAL_CHANS))
+	botnet_send_join_idx(idx, -1);
+      if (info_party) {
+	 char * p = get_user(&USERENTRY_INFO,dcc[idx].user);
+	 if (p) {
+	    char x[1024];
+	    chanout_but(-1,dcc[idx].u.chat->channel,
+			"*** [%s] %s\n", dcc[idx].nick, p);
+	    simple_sprintf(x,"[%s] %s",dcc[idx].nick,p);
+	    botnet_send_chan(-1,botnetnick,NULL,dcc[idx].u.chat->channel,
+			     x);
+	 }
       }
    }
    return 0;
