@@ -13,95 +13,58 @@
    COPYING that was distributed with this code.
  */
 
-#include "../module.h"
-#ifdef MODULES
-#include <sys/types.h>
-#include <sys/stat.h>
-#include "../../files.h"
-#include "filesys.h"
-#else
-extern char tempdir[];
-#endif
-#include "../../users.h"
-
-#ifndef NO_FILE_SYSTEM
-extern char dccdir[];
-#ifndef MODULES
-extern struct userrec *userlist;
-
-#else
-
-static
-#endif
-int tcl_getdesc STDVAR
+static int tcl_getdesc STDVAR
 {
-   char s[301];
-    BADARGS(3, 3, " dir file");
-    filedb_getdesc(argv[1], argv[2], s);
-    Tcl_AppendResult(irp, s, NULL);
-    return TCL_OK;
+   char s[186];
+   BADARGS(3, 3, " dir file");
+   filedb_getdesc(argv[1], argv[2], s);
+   Tcl_AppendResult(irp, s, NULL);
+   return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_setdesc STDVAR
+static int tcl_setdesc STDVAR
 {
    BADARGS(4, 4, " dir file desc");
    filedb_setdesc(argv[1], argv[2], argv[3]);
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_getowner STDVAR
+static int tcl_getowner STDVAR
 {
-   char s[121];
-    BADARGS(3, 3, " dir file");
-    filedb_getowner(argv[1], argv[2], s);
-    Tcl_AppendResult(irp, s, NULL);
-    return TCL_OK;
+   char s[HANDLEN+1];
+   BADARGS(3, 3, " dir file");
+   filedb_getowner(argv[1], argv[2], s);
+   Tcl_AppendResult(irp, s, NULL);
+   return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_setowner STDVAR
+static int tcl_setowner STDVAR
 {
    BADARGS(4, 4, " dir file owner");
    filedb_setowner(argv[1], argv[2], argv[3]);
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_getgots STDVAR
+static int tcl_getgots STDVAR
 {
    int i;
    char s[10];
-    BADARGS(3, 3, " dir file");
-    i = filedb_getgots(argv[1], argv[2]);
-    sprintf(s, "%d", i);
-    Tcl_AppendResult(irp, s, NULL);
-    return TCL_OK;
+   
+   BADARGS(3, 3, " dir file");
+   i = filedb_getgots(argv[1], argv[2]);
+   sprintf(s, "%d", i);
+   Tcl_AppendResult(irp, s, NULL);
+   return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_setlink STDVAR
+static int tcl_setlink STDVAR
 {
    BADARGS(4, 4, " dir file link");
    filedb_setlink(argv[1], argv[2], argv[3]);
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_getlink STDVAR
+static int tcl_getlink STDVAR
 {
    char s[121];
     BADARGS(3, 3, " dir file");
@@ -110,21 +73,14 @@ int tcl_getlink STDVAR
     return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_setpwd STDVAR
+static int tcl_setpwd STDVAR
 {
    int i, idx;
 
-    BADARGS(3, 3, " idx dir");
-    i = atoi(argv[1]);
-    idx = findidx(i);
-   if (idx < 0) {
-      Tcl_AppendResult(irp, "invalid idx", NULL);
-      return TCL_ERROR;
-   }
-   if (dcc[idx].type != DCC_FILES) {
+   BADARGS(3, 3, " idx dir");
+   i = atoi(argv[1]);
+   idx = findanyidx(i);
+   if ((idx < 0) || (dcc[idx].type != &DCC_FILES)) {
       Tcl_AppendResult(irp, "invalid idx", NULL);
       return TCL_ERROR;
    }
@@ -132,21 +88,14 @@ int tcl_setpwd STDVAR
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_getpwd STDVAR
+static int tcl_getpwd STDVAR
 {
    int i, idx;
 
-    BADARGS(2, 2, " idx");
-    i = atoi(argv[1]);
-    idx = findidx(i);
-   if (idx < 0) {
-      Tcl_AppendResult(irp, "invalid idx", NULL);
-      return TCL_ERROR;
-   }
-   if (dcc[idx].type != DCC_FILES) {
+   BADARGS(2, 2, " idx");
+   i = atoi(argv[1]);
+   idx = findanyidx(i);
+   if ((idx < 0) || (dcc[idx].type != &DCC_FILES)) {
       Tcl_AppendResult(irp, "invalid idx", NULL);
       return TCL_ERROR;
    }
@@ -154,77 +103,57 @@ int tcl_getpwd STDVAR
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_getfiles STDVAR
+static int tcl_getfiles STDVAR
 {
    BADARGS(2, 2, " dir");
    filedb_getfiles(irp, argv[1]);
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_getdirs STDVAR
+static int tcl_getdirs STDVAR
 {
    BADARGS(2, 2, " dir");
    filedb_getdirs(irp, argv[1]);
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_hide STDVAR
+static int tcl_hide STDVAR
 {
    BADARGS(3, 3, " dir file");
    filedb_change(argv[1], argv[2], FILEDB_HIDE);
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_unhide STDVAR
+static int tcl_unhide STDVAR
 {
    BADARGS(3, 3, " dir file");
    filedb_change(argv[1], argv[2], FILEDB_UNHIDE);
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_share STDVAR
+static int tcl_share STDVAR
 {
    BADARGS(3, 3, " dir file");
    filedb_change(argv[1], argv[2], FILEDB_SHARE);
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_unshare STDVAR
+static int tcl_unshare STDVAR
 {
    BADARGS(3, 3, " dir file");
    filedb_change(argv[1], argv[2], FILEDB_UNSHARE);
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_setflags STDVAR
+static int tcl_setflags STDVAR
 {
    FILE *f;
-   filedb *fdb;
-   int where;
+   filedb fdb;
+   long where = 0;
    char s[512], *p, *d;
-    BADARGS(2, 3, " dir ?flags?");
-    strcpy(s, argv[1]);
+   
+   BADARGS(2, 3, " dir ?flags ?channel??");
+   strcpy(s, argv[1]);
    if (s[strlen(s) - 1] == '/')
        s[strlen(s) - 1] = 0;
     p = strrchr(s, '/');
@@ -236,36 +165,42 @@ int tcl_setflags STDVAR
       p++;
       d = s;
    }
-   f = filedb_open(d);
-   fdb = findfile(f, p, &where);
-   if (fdb == NULL)
+   f = filedb_open(d,0);
+   if (!findmatch(f, p, &where, &fdb))
       Tcl_AppendResult(irp, "-1", NULL);	/* no such dir */
-   else if (!(fdb->stat & FILE_DIR))
+   else if (!(fdb.stat & FILE_DIR))
       Tcl_AppendResult(irp, "-2", NULL);	/* not a dir */
-   else if (argc == 3) {
-      flags2str(str2flags(argv[2]), s);
-      strncpy(fdb->flags_req, s, 10);
-      fdb->flags_req[10] = 0;
-   } else
-      fdb->flags_req[0] = 0;
+   else {
+      if (argc >= 3) {
+	 struct flag_record fr = { FR_GLOBAL|FR_CHAN, 0, 0, 0, 0, 0 };
+	 
+	 break_down_flags(argv[2],&fr,NULL);
+	 build_flags(s,&fr,NULL);
+	 strncpy(fdb.flags_req, s, 21);
+	 fdb.flags_req[21] = 0;
+      } else
+	fdb.flags_req[0] = 0;
+      if (argc == 4) {
+	 strncpy(fdb.chname,argv[3],80);
+	 fdb.chname[80] = 0;
+      } 
+   }
    fseek(f, where, SEEK_SET);
-   fwrite(fdb, sizeof(filedb), 1, f);
+   fwrite(&fdb, sizeof(filedb), 1, f);
    filedb_close(f);
    Tcl_AppendResult(irp, "0", NULL);
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_getflags STDVAR
+static int tcl_getflags STDVAR
 {
    FILE *f;
-   filedb *fdb;
-   int where;
+   filedb fdb;
+   long where = 0;
    char s[512], *p, *d;
-    BADARGS(2, 2, " dir");
-    strcpy(s, argv[1]);
+   
+   BADARGS(2, 2, " dir");
+   strcpy(s, argv[1]);
    if (s[strlen(s) - 1] == '/')
        s[strlen(s) - 1] = 0;
     p = strrchr(s, '/');
@@ -277,33 +212,32 @@ int tcl_getflags STDVAR
       p++;
       d = s;
    }
-   f = filedb_open(d);
-   fdb = findfile(f, p, &where);
-   if (fdb == NULL)
+   f = filedb_open(d, 0);
+   if (!findmatch(f, p, &where, &fdb))
       Tcl_AppendResult(irp, "", NULL);	/* no such dir */
-   else if (!(fdb->stat & FILE_DIR))
+   else if (!(fdb.stat & FILE_DIR))
       Tcl_AppendResult(irp, "", NULL);	/* not a dir */
    else {
-      strcpy(s, fdb->flags_req);
+      strcpy(s, fdb.flags_req);
       if (s[0] == '-')
 	 s[0] = 0;
-      Tcl_AppendResult(irp, s, NULL);
+      Tcl_AppendElement(irp, s);
+      Tcl_AppendElement(irp, fdb.chname);
    }
    filedb_close(f);
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_mkdir STDVAR
+static int tcl_mkdir STDVAR
 {
    char s[512], t[512], *d, *p;
    FILE *f;
-   filedb *fdb;
-   long where;
-    BADARGS(2, 3, " dir ?required-flags?");
-    strcpy(s, argv[1]);
+   filedb fdb;
+   long where = 0;
+   struct flag_record fr = { FR_GLOBAL|FR_CHAN, 0, 0, 0, 0, 0 };
+   
+   BADARGS(2, 3, " dir ?required-flags ?channel??");
+   strcpy(s, argv[1]);
    if (s[strlen(s) - 1] == '/')
        s[strlen(s) - 1] = 0;
     p = strrchr(s, '/');
@@ -315,67 +249,56 @@ int tcl_mkdir STDVAR
       p++;
       d = s;
    }
-   f = filedb_open(d);
-   fdb = findfile(f, p, &where);
-   if (fdb == NULL) {
-      filedb x;
+   f = filedb_open(d, 0);
+   if (!findmatch(f, p, &where, &fdb)) {
       sprintf(t, "%s%s/%s", dccdir, d, p);
-      if (mkdir(t, 0755) == 0) {
-	 x.version = FILEVERSION;
-	 x.stat = FILE_DIR;
-	 x.desc[0] = 0;
-	 x.uploader[0] = 0;
-	 strcpy(x.filename, argv[1]);
-	 x.flags_req[0] = 0;
-	 x.uploaded = time(NULL);
-	 x.size = 0;
-	 x.gots = 0;
-	 x.sharelink[0] = 0;
-	 Tcl_AppendResult(irp, "0", NULL);
-	 if (argc == 3) {
-	    char w[100];
-	    flags2str(str2flags(argv[2]), w);
-	    strncpy(x.flags_req, w, 10);
-	    x.flags_req[10] = 0;
-	 }
-	 where = findempty(f);
-	 fseek(f, where, SEEK_SET);
-	 fwrite(&x, sizeof(filedb), 1, f);
+      if (mkdir(t, 0755) != 0) {
+	 Tcl_AppendResult(irp, "1", NULL);
 	 filedb_close(f);
 	 return TCL_OK;
       }
-      Tcl_AppendResult(irp, "1", NULL);
-      filedb_close(f);
-      return TCL_OK;
-   }
-   /* already exists! */
-   if (!(fdb->stat & FILE_DIR)) {
+      fdb.version = FILEVERSION;
+      fdb.stat = FILE_DIR;
+      fdb.desc[0] = 0;
+      fdb.uploader[0] = 0;
+      strcpy(fdb.filename, argv[1]);
+      fdb.flags_req[0] = 0;
+      fdb.uploaded = now;
+      fdb.size = 0;
+      fdb.gots = 0;
+      fdb.sharelink[0] = 0;
+      where = findempty(f);
+   } else if (!(fdb.stat & FILE_DIR)) {
       Tcl_AppendResult(irp, "2", NULL);
       filedb_close(f);
       return TCL_OK;
    }
-   if (argc == 3) {
-      flags2str(str2flags(argv[2]), s);
-      strncpy(fdb->flags_req, s, 10);
-      fdb->flags_req[10] = 0;
+   if (argc >= 3) {
+      break_down_flags(argv[2],&fr,NULL);
+      build_flags(s,&fr,NULL);
+      strncpy(fdb.flags_req, s, 21);
+      fdb.flags_req[21] = 0;
    } else {
-      fdb->flags_req[0] = 0;
+      fdb.flags_req[0] = 0;
    }
+   if (argc == 4) {
+      strncpy(fdb.chname,argv[3],80);
+      fdb.chname[80] = 0;
+   } else
+     fdb.chname[0] = 0;
    Tcl_AppendResult(irp, "0", NULL);
    fseek(f, where, SEEK_SET);
-   fwrite(fdb, sizeof(filedb), 1, f);
+   fwrite(&fdb, sizeof(filedb), 1, f);
    filedb_close(f);
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_rmdir STDVAR
+static int tcl_rmdir STDVAR
 {
    FILE *f;
-   filedb *fdb;
-   long where;
+   filedb fdb;
+   long where = 0;
+   
    char s[256], t[512], *d, *p;
     BADARGS(2, 2, " dir");
    if (strlen(argv[1]) > 80)
@@ -392,14 +315,13 @@ int tcl_rmdir STDVAR
       p++;
       d = s;
    }
-   f = filedb_open(d);
-   fdb = findfile(f, p, &where);
-   if (fdb == NULL) {
+   f = filedb_open(d,0);
+   if  (!findmatch(f, p, &where, &fdb)) {
       Tcl_AppendResult(irp, "1", NULL);
       filedb_close(f);
       return TCL_OK;
    }
-   if (!(fdb->stat & FILE_DIR)) {
+   if (!(fdb.stat & FILE_DIR)) {
       Tcl_AppendResult(irp, "1", NULL);
       filedb_close(f);
       return TCL_OK;
@@ -411,9 +333,9 @@ int tcl_rmdir STDVAR
    unlink(t);
    sprintf(t, "%s%s/%s", dccdir, d, p);
    if (rmdir(t) == 0) {
-      fdb->stat |= FILE_UNUSED;
+      fdb.stat |= FILE_UNUSED;
       fseek(f, where, SEEK_SET);
-      fwrite(fdb, sizeof(filedb), 1, f);
+      fwrite(&fdb, sizeof(filedb), 1, f);
       filedb_close(f);
       Tcl_AppendResult(irp, "0", NULL);
       return TCL_OK;
@@ -423,18 +345,16 @@ int tcl_rmdir STDVAR
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_mv_cp PROTO4(Tcl_Interp *, irp, int, argc, char **, argv, int, copy)
+static int tcl_mv_cp (Tcl_Interp * irp, int argc, char ** argv, int copy)
 {
    char *p, fn[161], oldpath[161], s[161], s1[161], newfn[161], newpath[161];
-   int ok, only_first, skip_this;
+   int ok, only_first, skip_this, ret, ret2;
    FILE *f, *g;
-   filedb *fdb, x, *z;
+   filedb fdb, x;
    long where, gwhere, wherez;
 
    BADARGS(3, 3, " oldfilepath newfilepath");
+   context;
    strcpy(fn, argv[1]);
    p = strrchr(fn, '/');
    if (p != NULL) {
@@ -442,8 +362,8 @@ int tcl_mv_cp PROTO4(Tcl_Interp *, irp, int, argc, char **, argv, int, copy)
       strncpy(s, fn, 160);
       s[160] = 0;
       strcpy(fn, p + 1);
-      if (!resolve_dir("/", s, oldpath, USER_OWNER | USER_BOT)) {	/* tcl can do
-									 * anything */
+      if (!resolve_dir("/", s, oldpath, -1)) {
+	 /* tcl can do * anything */
 	 Tcl_AppendResult(irp, "-1", NULL);	/* invalid source */
 	 return TCL_OK;
       }
@@ -451,7 +371,7 @@ int tcl_mv_cp PROTO4(Tcl_Interp *, irp, int, argc, char **, argv, int, copy)
       strcpy(oldpath, "/");
    strncpy(s, argv[2], 160);
    s[160] = 0;
-   if (!resolve_dir("/", s, newpath, USER_OWNER | USER_BOT)) {
+   if (!resolve_dir("/", s, newpath, -1)) {
       /* destination is not just a directory */
       p = strrchr(s, '/');
       if (p == NULL) {
@@ -461,7 +381,7 @@ int tcl_mv_cp PROTO4(Tcl_Interp *, irp, int, argc, char **, argv, int, copy)
 	 *p = 0;
 	 strcpy(newfn, p + 1);
       }
-      if (!resolve_dir("/", s, newpath, USER_OWNER | USER_BOT)) {
+      if (!resolve_dir("/", s, newpath, -1)) {
 	 Tcl_AppendResult(irp, "-2", NULL);	/* invalid desto */
 	 return TCL_OK;
       }
@@ -478,74 +398,77 @@ int tcl_mv_cp PROTO4(Tcl_Interp *, irp, int, argc, char **, argv, int, copy)
       only_first = 1;
    else
       only_first = 0;
-   f = filedb_open(oldpath);
-   if (strcmp(oldpath, newpath) == 0)
+   f = filedb_open(oldpath, 0);
+   if (!strcmp(oldpath, newpath))
       g = NULL;
    else
-      g = filedb_open(newpath);
+      g = filedb_open(newpath, 0);
    where = 0L;
    ok = 0;
-   fdb = findmatch(f, fn, &where);
-   if (fdb == NULL) {
+   ret = findmatch(f, fn, &where, &fdb);
+   if (!ret) {
       Tcl_AppendResult(irp, "-4", NULL);	/* nomatch */
       filedb_close(f);
       if (g != NULL)
 	 filedb_close(g);
       return TCL_OK;
    }
-   while (fdb != NULL) {
+   while (ret) {
       skip_this = 0;
-      if (!(fdb->stat & (FILE_HIDDEN | FILE_DIR))) {
-	 sprintf(s, "%s%s%s%s", dccdir, oldpath, oldpath[0] ? "/" : "", fdb->filename);
-	 sprintf(s1, "%s%s%s%s", dccdir, newpath, newpath[0] ? "/" : "", newfn[0] ?
-		 newfn : fdb->filename);
+      if (!(fdb.stat & (FILE_HIDDEN | FILE_DIR))) {
+	 sprintf(s, "%s%s%s%s", dccdir, oldpath,
+		 oldpath[0] ? "/" : "", fdb.filename);
+	 sprintf(s1, "%s%s%s%s", dccdir, newpath,
+		 newpath[0] ? "/" : "", newfn[0] ? newfn : fdb.filename);
 	 if (strcmp(s, s1) == 0) {
 	    Tcl_AppendResult(irp, "-3", NULL);	/* stoopid copy to self */
 	    skip_this = 1;
 	 }
 	 /* check for existence of file with same name in new dir */
-	 if (g == NULL)
-	    z = findfile2(f, newfn[0] ? newfn : fdb->filename, &wherez);
+	 wherez = 0;
+	 if (!g)
+	    ret2 = findmatch(f, newfn[0] ? newfn : fdb.filename, &wherez, &x);
 	 else
-	    z = findfile2(g, newfn[0] ? newfn : fdb->filename, &wherez);
-	 if (z != NULL) {
+	    ret2 = findmatch(g, newfn[0] ? newfn : fdb.filename, &wherez, &x);
+	 if (ret2) {
 	    /* it's ok if the entry in the new dir is a normal file (we'll */
 	    /* just scrap the old entry and overwrite the file) -- but if */
 	    /* it's a directory, this file has to be skipped */
-	    if (z->stat & FILE_DIR) {
+	    if (x.stat & FILE_DIR) {
 	       /* skip */
 	       skip_this = 1;
 	    } else {
-	       z->stat |= FILE_UNUSED;
-	       if (g == NULL) {
+	       x.stat |= FILE_UNUSED;
+	       if (!g) {
 		  fseek(f, wherez, SEEK_SET);
-		  fwrite(z, sizeof(filedb), 1, f);
+		  fwrite(&x, sizeof(filedb), 1, f);
 	       } else {
 		  fseek(g, wherez, SEEK_SET);
-		  fwrite(z, sizeof(filedb), 1, g);
+		  fwrite(&x, sizeof(filedb), 1, g);
 	       }
 	    }
 	 }
 	 if (!skip_this) {
-	    if ((fdb->sharelink[0]) || (copyfile(s, s1) == 0)) {
+	    if ((fdb.sharelink[0]) || (copyfile(s, s1) == 0)) {
 	       /* raw file moved okay: create new entry for it */
 	       ok++;
-	       if (g == NULL)
+	       if (!g)
 		  gwhere = findempty(f);
 	       else
 		  gwhere = findempty(g);
 	       x.version = FILEVERSION;
-	       x.stat = fdb->stat;
-	       x.flags_req[0] = 0;
-	       strcpy(x.filename, fdb->filename);
-	       strcpy(x.desc, fdb->desc);
+	       x.stat = fdb.stat;
+	       strcpy(x.flags_req, fdb.flags_req);
+	       strcpy(x.chname, fdb.chname);
+	       strcpy(x.filename, fdb.filename);
+	       strcpy(x.desc, fdb.desc);
 	       if (newfn[0])
 		  strcpy(x.filename, newfn);
-	       strcpy(x.uploader, fdb->uploader);
-	       x.uploaded = fdb->uploaded;
-	       x.size = fdb->size;
-	       x.gots = fdb->gots;
-	       strcpy(x.sharelink, fdb->sharelink);
+	       strcpy(x.uploader, fdb.uploader);
+	       x.uploaded = fdb.uploaded;
+	       x.size = fdb.size;
+	       x.gots = fdb.gots;
+	       strcpy(x.sharelink, fdb.sharelink);
 	       if (g == NULL) {
 		  fseek(f, gwhere, SEEK_SET);
 		  fwrite(&x, sizeof(filedb), 1, f);
@@ -555,17 +478,17 @@ int tcl_mv_cp PROTO4(Tcl_Interp *, irp, int, argc, char **, argv, int, copy)
 	       }
 	       if (!copy) {
 		  unlink(s);
-		  fdb->stat |= FILE_UNUSED;
+		  fdb.stat |= FILE_UNUSED;
 		  fseek(f, where, SEEK_SET);
-		  fwrite(fdb, sizeof(filedb), 1, f);
+		  fwrite(&fdb, sizeof(filedb), 1, f);
 	       }
 	    }
 	 }
       }
       where += sizeof(filedb);
-      fdb = findmatch(f, fn, &where);
+      ret = findmatch(f, fn, &where, &fdb);
       if ((ok) && (only_first))
-	 fdb = NULL;
+	 ret = 0;
    }
    if (!ok)
       Tcl_AppendResult(irp, "-4", NULL);	/* nomatch */
@@ -575,43 +498,30 @@ int tcl_mv_cp PROTO4(Tcl_Interp *, irp, int, argc, char **, argv, int, copy)
       Tcl_AppendResult(irp, x, NULL);
    }
    filedb_close(f);
-   if (g != NULL)
+   if (g)
       filedb_close(g);
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_mv STDVAR
+static int tcl_mv STDVAR
 {
    return tcl_mv_cp(irp, argc, argv, 0);
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_cp STDVAR
+static int tcl_cp STDVAR
 {
    return tcl_mv_cp(irp, argc, argv, 1);
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_filesend STDVAR
+static int tcl_filesend STDVAR
 {
    int i, idx;
-   char s[10];
+   char s[HANDLEN+1];
 
-    BADARGS(3, 4, " idx filename ?nick?");
-    i = atoi(argv[1]);
-    idx = findidx(i);
-   if (idx < 0) {
-      Tcl_AppendResult(irp, "invalid idx", NULL);
-      return TCL_ERROR;
-   }
-   if (dcc[idx].type != DCC_FILES) {
+   BADARGS(3, 4, " idx filename ?nick?");
+   i = atoi(argv[1]);
+   idx = findanyidx(i);
+   if ((idx < 0) || (dcc[idx].type != &DCC_FILES)) {
       Tcl_AppendResult(irp, "invalid idx", NULL);
       return TCL_ERROR;
    }
@@ -624,60 +534,57 @@ int tcl_filesend STDVAR
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_getuploads STDVAR
+static int tcl_getuploads STDVAR
 {
    struct userrec *u;
+   struct filesys_stats * fs;
    char s[81];
-    BADARGS(2, 2, " handle");
-    u = get_user_by_handle(userlist, argv[1]);
-   if (u == NULL)
-       return TCL_OK;
-    sprintf(s, "%u %lu", u->uploads, u->upload_k);
-    Tcl_AppendResult(irp, s, NULL);
-    return TCL_OK;
+   
+   BADARGS(2, 2, " handle");
+   u = get_user_by_handle(userlist, argv[1]);
+   if (u) {
+      fs = get_user(&USERENTRY_FSTAT,u);
+      if (fs) {
+	 sprintf(s, "%u %u", fs->uploads, fs->upload_ks);
+	 Tcl_AppendResult(irp, s, NULL);
+      }
+   }
+   return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_getdnloads STDVAR
+static int tcl_getdnloads STDVAR
 {
    struct userrec *u;
+   struct filesys_stats * fs;
    char s[81];
+   
     BADARGS(2, 2, " handle");
     u = get_user_by_handle(userlist, argv[1]);
-   if (u == NULL)
-       return TCL_OK;
-    sprintf(s, "%u %lu", u->dnloads, u->dnload_k);
-    Tcl_AppendResult(irp, s, NULL);
-    return TCL_OK;
+   if (u) {
+      fs = get_user(&USERENTRY_FSTAT,u);
+      if (fs) {
+	 sprintf(s, "%u %u", fs->dnloads, fs->dnload_ks);
+	 Tcl_AppendResult(irp, s, NULL);
+      }
+   }
+   return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_setuploads STDVAR
+static int tcl_setuploads STDVAR
 {
    BADARGS(4, 4, " handle files k");
    set_handle_uploads(userlist, argv[1], atoi(argv[2]), atoi(argv[3]));
    return TCL_OK;
 }
 
-#ifdef MODULES
-static
-#endif
-int tcl_setdnloads STDVAR
+static int tcl_setdnloads STDVAR
 {
    BADARGS(4, 4, " handle files k");
    set_handle_dnloads(userlist, argv[1], atoi(argv[2]), atoi(argv[3]));
    return TCL_OK;
 }
 
-#ifdef MODULES
-tcl_cmds mytcls[] =
+static tcl_cmds mytcls[] =
 {
    {"getdesc", tcl_getdesc},
    {"getowner", tcl_getowner},
@@ -707,5 +614,3 @@ tcl_cmds mytcls[] =
    {"setflags", tcl_setflags},
    {0, 0}
 };
-#endif
-#endif
