@@ -17,12 +17,12 @@ static p_tcl_bind_list H_topc, H_splt, H_sign, H_rejn, H_part, H_pub, H_pubm;
 static p_tcl_bind_list H_nick, H_mode, H_kick, H_join;
 static Function * global = NULL, *channels_funcs = NULL, *server_funcs = NULL;
 
-
 /* time to wait for user to return for net-split */
 static int wait_split = 300;
 static int bounce_bans = 0;
 static int learn_users = 0;
 static int wait_info = 15;
+static int invite_key = 1;
 /* number of modes per line to send */
 static int modesperline = 3;
 /* maximum bytes to send in 1 mode */
@@ -32,6 +32,7 @@ static int use_354 = 0;
 /* how many kicks does the irc network support at once?
    0 = as many as possible.  Ernst 18/3/98 */
 static int kick_method = 1;
+static int allow_desync = 0;
 
 #include "chan.c"
 #include "mode.c"
@@ -275,9 +276,9 @@ static void log_chans()
 	    bans++;
 	    b = b->next;
 	 }
-	 putlog(LOG_MISC, chan->name, "%-10s: %2d member%c (%2d chop%c), %2d ban%c %s",
+	 putlog(LOG_MISC, chan->name, "%-10s: %d member%c (%d chop%s, %2d ba%s %s",
 		chan->name, chan->channel.members, chan->channel.members == 1 ? ' ' : 's',
-		chops, chops == 1 ? ' ' : 's', bans, bans == 1 ? ' ' : 's', me_op(chan) ? "" :
+		chops, chops == 1 ? ")" : "s)", bans, bans == 1 ? "n" : "ns", me_op(chan) ? "" :
 		"(not op'd)");
       }
       chan = chan->next;
@@ -486,9 +487,9 @@ static void check_tcl_joinpart (char * nick, char * uhost, struct userrec * u,
    context;
 }
 
-static void check_tcl_signtopcnickmode (char * nick, char * uhost, struct userrec * u,
-					char * chname, char * reason,
-					p_tcl_bind_list table)
+static void check_tcl_signtopcnick (char * nick, char * uhost, struct userrec * u,
+				    char * chname, char * reason,
+				    p_tcl_bind_list table)
 {
    struct flag_record fr = {FR_GLOBAL|FR_CHAN,0,0,0,0,0};
    char args[1024];
@@ -510,15 +511,18 @@ static void check_tcl_signtopcnickmode (char * nick, char * uhost, struct userre
    context;
 }
 
-static void check_tcl_kick (char * nick, char * uhost, struct userrec * u,
-			    char * chname, char * dest, char * reason)
-{
+static void check_tcl_kickmode (char * nick, char * uhost, struct userrec * u,
+				char * chname, char * dest, char * reason,
+				p_tcl_bind_list table) {
    struct flag_record fr = {FR_GLOBAL|FR_CHAN,0,0,0,0,0};
    char args[512];
    
    context;
    get_user_flagrec(u,&fr,chname);
-   simple_sprintf(args, "%s %s", chname, dest);
+   if (table == H_mode)
+     simple_sprintf(args, "%s %s", chname, dest);
+   else
+     simple_sprintf(args, "%s %s %s", chname, dest, reason);
    Tcl_SetVar(interp, "_kick1", nick, 0);
    Tcl_SetVar(interp, "_kick2", uhost, 0);
    Tcl_SetVar(interp, "_kick3", u?u->handle:"*", 0);
@@ -526,7 +530,7 @@ static void check_tcl_kick (char * nick, char * uhost, struct userrec * u,
    Tcl_SetVar(interp, "_kick5", dest, 0);
    Tcl_SetVar(interp, "_kick6", reason, 0);
    context;
-   check_tcl_bind(H_kick, args, &fr, " $_kick1 $_kick2 $_kick3 $_kick4 $_kick5 $_kick6",
+   check_tcl_bind(table, args, &fr, " $_kick1 $_kick2 $_kick3 $_kick4 $_kick5 $_kick6",
 		  MATCH_MASK | BIND_USE_ATTR | BIND_STACKABLE);
    context;
 }
@@ -594,6 +598,8 @@ static tcl_ints myints[] =
      {"mode-buf-length" , &mode_buf_len, 0},
      {"use-354", &use_354, 0},
      {"kick-method", &kick_method, 0},
+     {"invite-key", &invite_key, 0},
+     {"allow-desync", &allow_desync, 0},
      {0,0}
 };
 
@@ -642,7 +648,7 @@ static void irc_report (int idx, int details)
    }
    if (k > 10) {
       q[k-2] = 0;
-      dprintf(idx,"   %s\n",q);
+      dprintf(idx,"    %s\n",q);
    }
 }
 
@@ -675,7 +681,7 @@ static char *irc_close()
    context;
    rem_tcl_ints(myints);
    rem_builtins(H_dcc,irc_dcc,16);
-   rem_builtins(H_msg,C_msg,17);
+   rem_builtins(H_msg,C_msg,19);
    rem_builtins(H_raw,irc_raw,24);
    rem_tcl_commands(tclchan_cmds);
    rem_help_reference("irc.help");
@@ -714,6 +720,8 @@ static Function irc_table[] =
      (Function) &H_pub ,
      (Function) &H_topc,
      (Function) recheck_channel,
+     /* 16 - 19 */
+     (Function) me_op,
 };
 
 char *server_start ();
@@ -744,7 +752,7 @@ char *irc_start (Function* global_funcs)
    context;
    add_tcl_ints(myints);
    add_builtins(H_dcc,irc_dcc,16);
-   add_builtins(H_msg,C_msg,17);
+   add_builtins(H_msg,C_msg,19);
    add_builtins(H_raw,irc_raw,24);
    add_tcl_commands(tclchan_cmds);
    add_help_reference("irc.help");
@@ -755,7 +763,7 @@ char *irc_start (Function* global_funcs)
    H_rejn = add_bind_table("rejn",HT_STACKABLE,channels_4char);
    H_part = add_bind_table("part",HT_STACKABLE,channels_4char);
    H_nick = add_bind_table("nick",HT_STACKABLE,channels_5char);
-   H_mode = add_bind_table("mode",HT_STACKABLE,channels_5char);
+   H_mode = add_bind_table("mode",HT_STACKABLE,channels_6char);
    H_kick = add_bind_table("kick",HT_STACKABLE,channels_6char);
    H_join = add_bind_table("join",HT_STACKABLE,channels_4char);
    H_pubm = add_bind_table("pubm",HT_STACKABLE,channels_5char);
