@@ -29,8 +29,7 @@ static int reversing = 0;
 static struct flag_record user = {FR_GLOBAL|FR_CHAN,0,0,0,0,0};
 static struct flag_record victim = {FR_GLOBAL|FR_CHAN,0,0,0,0,0};
 
-static void flush_mode (struct chanset_t * chan, int pri)
-{
+static void flush_mode (struct chanset_t * chan, int pri) {
    char *p, out[512], post[512];
    int i, ok = 0;
    p = out;
@@ -67,14 +66,28 @@ static void flush_mode (struct chanset_t * chan, int pri)
    }
    chan->limit = (-1);
    chan->key[0] = 0;
+   /* do -b before +b to avoid server ban overlap ignores */
+   for (i = 0; i < modesperline; i++)
+      if ((chan->cmode[i].type & MINUS) && (chan->cmode[i].type & BAN)) {
+	 if (ok < 2) {
+	    *p++ = '-';
+	    ok = 2;
+	 }
+	 *p++ = 'b';
+	 strcat(post, chan->cmode[i].op);
+	 strcat(post, " ");
+	 nfree(chan->cmode[i].op);
+	 chan->cmode[i].op = NULL;
+      }
+   ok &= 1;
    for (i = 0; i < modesperline; i++)
       if (chan->cmode[i].type & PLUS) {
 	 if (!ok) {
 	    *p++ = '+';
 	    ok = 1;
 	 }
-	 *p++ = (chan->cmode[i].type & 
-			BAN ? 'b' : (chan->cmode[i].type & CHOP ? 'o' : 'v'));
+	 *p++ = ((chan->cmode[i].type & BAN) ? 'b' : 
+		 ((chan->cmode[i].type & CHOP) ? 'o' : 'v'));
 	 strcat(post, chan->cmode[i].op);
 	 strcat(post, " ");
 	 nfree(chan->cmode[i].op);
@@ -93,13 +106,12 @@ static void flush_mode (struct chanset_t * chan, int pri)
    }
    chan->rmkey[0] = 0;
    for (i = 0; i < modesperline; i++)
-      if (chan->cmode[i].type & MINUS) {
+     if ((chan->cmode[i].type & MINUS) && !(chan->cmode[i].type & BAN)) {
 	 if (!ok) {
 	    *p++ = '-';
 	    ok = 1;
 	 }
-	 *p++ = (chan->cmode[i].type & 
-			BAN ? 'b' : (chan->cmode[i].type & CHOP ? 'o' : 'v'));
+	 *p++ = (chan->cmode[i].type & CHOP) ? 'o' : 'v';
 	 strcat(post, chan->cmode[i].op);
 	 strcat(post, " ");
 	 nfree(chan->cmode[i].op);
@@ -124,8 +136,7 @@ static void flush_mode (struct chanset_t * chan, int pri)
 
 /* queue a channel mode change */
 static void real_add_mode (struct chanset_t * chan, 
-	       char plus, char mode, char * op)
-{
+	       char plus, char mode, char * op) {
    int i, type, ok, l;
    char s[21];
 
@@ -167,33 +178,29 @@ static void real_add_mode (struct chanset_t * chan,
       return;
    }
    /* +k ? store key */
-   if ((plus == '+') && (mode == 'k')) {
-      strcpy(chan->key, op);
-      return;
-   }
+   if ((plus == '+') && (mode == 'k')) 
+     strcpy(chan->key, op);
    /* -k ? store removed key */
-   if ((plus == '-') && (mode == 'k')) {
-      strcpy(chan->rmkey, op);
-      return;
-   }
+   else if ((plus == '-') && (mode == 'k')) 
+     strcpy(chan->rmkey, op);
    /* +l ? store limit */
-   if ((plus == '+') && (mode == 'l')) {
-      chan->limit = atoi(op);
-      return;
-   }
-   /* typical mode changes */
-   if (plus == '+')
-      strcpy(s, chan->pls);
-   else
-      strcpy(s, chan->mns);
-   if (strchr(s, mode) != NULL)
-      return;			/* duplicate */
-   if (plus == '+') {
-      chan->pls[strlen(chan->pls) + 1] = 0;
-      chan->pls[strlen(chan->pls)] = mode;
-   } else {
-      chan->mns[strlen(chan->mns) + 1] = 0;
-      chan->mns[strlen(chan->mns)] = mode;
+   else if ((plus == '+') && (mode == 'l')) 
+     chan->limit = atoi(op);
+   else {
+      /* typical mode changes */
+      if (plus == '+')
+	strcpy(s, chan->pls);
+      else
+	strcpy(s, chan->mns);
+      if (!strchr(s, mode)) {
+	 if (plus == '+') {
+	    chan->pls[strlen(chan->pls) + 1] = 0;
+	    chan->pls[strlen(chan->pls)] = mode;
+	 } else {
+	    chan->mns[strlen(chan->mns) + 1] = 0;
+	    chan->mns[strlen(chan->mns)] = mode;
+	 }
+      }
    }
 }
 
@@ -574,11 +581,11 @@ static void got_unban (struct chanset_t * chan, char * nick, char * from,
 }
 
 /* a pain in the ass: mode changes */
-static void gotmode (char * from, char * msg)
-{
+static void gotmode (char * from, char * msg) {
    char * nick, *ch, *op, *chg;
-   char s[UHOSTLEN], ms[UHOSTLEN];
+   char s[UHOSTLEN];
    char ms2[3];
+   int z;
    struct userrec * u;
    memberlist *m;
    struct chanset_t *chan;
@@ -593,26 +600,33 @@ static void gotmode (char * from, char * msg)
 	 putlog(LOG_MISC, "*", CHAN_FORCEJOIN, ch);
 	 dprintf(DP_SERVER, "PART %s\n", ch);
       } else if (!channel_pending(chan)) {
+	 z = strlen(msg);
+         if (msg[--z] == ' ') /* i hate cosmetic bugs :P -poptix */
+           msg[z] = 0;
 	 putlog(LOG_MODES, chan->name, "%s: mode change '%s %s' by %s", 
 		ch, chg, msg, from);
 	 u = get_user_by_host(from);
 	 get_user_flagrec(u,&user,ch);
 	 nick = splitnick(&from);
 	 m = ismember(chan, nick);
-	 if (m && me_op(chan)) {
-	    if (chan_fakeop(m)) {
-	       putlog(LOG_MODES, ch, CHAN_FAKEMODE, ch);
-	       dprintf(DP_MODE, "KICK %s %s :%s\n", ch, nick, CHAN_FAKEMODE_KICK);
-	       reversing = 1;
-	    } else if (!chan_hasop(m)) {
+	 if (allow_desync == 0) {
+	   if (m && me_op(chan)) {
+	     if (chan_fakeop(m)) {
+	        putlog(LOG_MODES, ch, CHAN_FAKEMODE, ch);
+	        dprintf(DP_MODE, "KICK %s %s :%s\n", ch, nick,
+              CHAN_FAKEMODE_KICK);
+	        reversing = 1;
+	     } else if (!chan_hasop(m)) {
 	       putlog(LOG_MODES, ch, CHAN_DESYNCMODE, ch);
-	       dprintf(DP_MODE, "KICK %s %s :%s\n", ch, nick, CHAN_DESYNCMODE_KICK);
+	       dprintf(DP_MODE, "KICK %s %s :%s\n", ch, nick,
+             CHAN_DESYNCMODE_KICK);
 	       reversing = 1;
-	    }
+	     }
+	   }
 	 }
 	 ms2[0] = '+';
 	 ms2[2] = 0;
-	 while (*chg) {
+	 while ((ms2[1] = *chg)) {
 	    int todo =0;
 	    
 	    switch (*chg) {
@@ -648,7 +662,7 @@ static void gotmode (char * from, char * msg)
 	       break;
 	     case 'l':
 	       if (ms2[0] == '-') {
-		  check_tcl_mode(nick, from, u, chan->name, "-l");
+		  check_tcl_mode(nick, from, u, chan->name, ms2, "");
 		  if ((reversing) && (chan->channel.maxmembers != (-1))) {
 		     simple_sprintf(s, "%d", chan->channel.maxmembers);
 		     add_mode(chan, '+', 'l', s);
@@ -662,8 +676,8 @@ static void gotmode (char * from, char * msg)
 		  op = newsplit(&msg);
 		  fixcolon(op);
 		  chan->channel.maxmembers = atoi(op);
-		  simple_sprintf(ms, "+l %d", chan->channel.maxmembers);
-		  check_tcl_mode(nick, from, u, chan->name, ms);
+		  check_tcl_mode(nick, from, u, chan->name, ms2,
+				 int_to_base10(chan->channel.maxmembers));
 		  if ((reversing) ||
 		      ((chan->mode_mns_prot & CHANLIMIT) && !glob_master(user)
 		       && !chan_master(user))) {
@@ -682,8 +696,7 @@ static void gotmode (char * from, char * msg)
 	      case 'k':
 	       op = newsplit(&msg);
 	       fixcolon(op);
-	       simple_sprintf(ms, "%ck %s", ms2[0], op);
-	       check_tcl_mode(nick, from, u, chan->name, ms);
+	       check_tcl_mode(nick, from, u, chan->name, ms2, op);
 	       if (ms2[0] == '+')
 		 got_key(chan, nick, from, op);
 	       else {
@@ -698,8 +711,7 @@ static void gotmode (char * from, char * msg)
 	      case 'o':
 	       op = newsplit(&msg);
 	       fixcolon(op);
-	       simple_sprintf(ms, "%co %s", ms2[0], op);
-	       check_tcl_mode(nick, from, u, chan->name, ms);
+	       check_tcl_mode(nick, from, u, chan->name, ms2, op);
 	       if (ms2[0] == '+')
 		 got_op(chan, nick, from, op, &user);
 	       else
@@ -714,8 +726,7 @@ static void gotmode (char * from, char * msg)
 			 CHAN_BADCHANMODE, CHAN_BADCHANMODE_ARGS2);
 		  dprintf(DP_MODE, "WHO %s\n", op);
 	       } else {
-		  simple_sprintf(ms, "%cv %s", ms2[0], op);
-		  check_tcl_mode(nick, from, u, chan->name, ms);
+		  check_tcl_mode(nick, from, u, chan->name, ms2, op);
 		  get_user_flagrec(m->user,&victim,chan->name);
 		  if (ms2[0] == '+') {
 		     m->flags &= ~SENTVOICE;
@@ -745,8 +756,7 @@ static void gotmode (char * from, char * msg)
 	      case 'b':
 	       op = newsplit(&msg);
 	       fixcolon(op);
-	       simple_sprintf(ms, "%cb %s", ms2[0], op);
-	       check_tcl_mode(nick, from, u, chan->name, ms);
+	       check_tcl_mode(nick, from, u, chan->name, ms2, op);
 	       if (ms2[0] == '+')
 		 got_ban(chan, nick, from, op);
 	       else
@@ -754,8 +764,7 @@ static void gotmode (char * from, char * msg)
 	       break;
 	    }
 	    if (todo) {
-	       ms2[1] = *chg; 
-	       check_tcl_mode(nick,from,u,chan->name,ms2);
+	       check_tcl_mode(nick,from,u,chan->name,ms2, "");
 	       if (ms2[0] == '+')
 		 chan->channel.mode |= todo;
 	       else
