@@ -93,7 +93,7 @@
 /* 52 - 55 */
 #define addhost_by_handle ((void (*) (char *, char *))global[52])
 #define delhost_by_handle ((int(*)(char *,char *))global[53])
-#define readuserfile ((int (*)(char *,struct userrec **,int))global[54])
+#define readuserfile ((int (*)(char *,struct userrec **))global[54])
 #define write_userfile ((void(*)(int))global[55])
 /* 56 - 59 */
 #define geticon ((char (*) (int))global[56])
@@ -291,6 +291,9 @@
 #define check_dcc_chanattrs ((int (*)(struct userrec *,char *,int,int))global[208])
 #define add_tcl_coups ((void (*) (tcl_coups *))global[209])
 #define rem_tcl_coups ((void (*) (tcl_coups *))global[210])
+#define botname ((char *)(global[211]))
+/* 212 - ??? */
+#define remove_gunk ((void(*)(char *))global[212])
 
 /* this is for blowfish module, couldnt be bothereed making a whole new .h 
  * file for it ;) */
