@@ -13,8 +13,6 @@
 static int serv;
 /* strict masking of hosts ? */
 static int strict_host;
-/* current bot name on irc */
-static char botname[NICKLEN];
 /* new server? */
 static char newserver[121];
 /* new server port? */
@@ -488,10 +486,10 @@ static char * traced_botname (ClientData cdata, Tcl_Interp * irp, char * name1,
 
 static tcl_strings my_tcl_strings[] =
 {
+   {"botnick", 0, 0, STR_PROTECT},
    {"altnick", altnick, NICKMAX, 0},
    {"realname", botrealname, 80, 0},
    {"init-server", initserver, 120, 0},
-   {"botnick", botname, 0, STR_PROTECT},
    {0, 0, 0, 0}
 };
 
@@ -786,7 +784,8 @@ static void getmyhostname (char * s)
    }
    p = getenv("HOSTNAME");
    if (p != NULL) {
-      strcpy(s, p);
+      strncpy(s, p, 80);
+      s[80] = 0;
       if (strchr(s, '.') != NULL)
 	 return;
    }
@@ -898,7 +897,7 @@ static Function server_table[] =
      (Function) server_expmem,
      (Function) server_report,
      /* 4 - 7 */
-     (Function) botname,      /* char * */
+     (Function) 0,      /* char * */
      (Function) botuserhost,  /* char * */
      (Function) &quiet_reject,/* int */
      (Function) &serv,
@@ -985,6 +984,7 @@ char *server_start (Function * global_funcs)
    maxqmsg = 300;
    burst = 0;
    context;
+   server_table[4] = (Function)botname;
    module_register(MODULE_NAME, server_table, 1, 0);
    if (!module_depend(MODULE_NAME, "eggdrop", 103, 13))
      return "This module requires eggdrop1.3.13 or later";
@@ -1017,11 +1017,12 @@ char *server_start (Function * global_funcs)
    H_ctcr = add_bind_table("ctcr",HT_STACKABLE,server_6char);
    H_ctcp = add_bind_table("ctcp",HT_STACKABLE,server_6char);
    context;
-   add_builtins(H_raw,my_raw_binds,16);
+   add_builtins(H_raw,my_raw_binds,17);
    add_builtins(H_dcc,C_dcc_serv,4);
    add_builtins(H_ctcp,my_ctcps,1);
    add_help_reference("server.help");
    context;
+   my_tcl_strings[0].buf = botname;
    add_tcl_strings(my_tcl_strings);
    my_tcl_ints[0].val = &use_silence;
    my_tcl_ints[1].val = &use_console_r;
