@@ -405,6 +405,9 @@ Function global_table [] =
      (Function) check_dcc_chanattrs,
      (Function) add_tcl_coups,
      (Function) rem_tcl_coups,
+     (Function) botname,
+     /* 212 - ??? */
+     (Function) remove_gunk,
 };
 
 void init_modules(void)
