@@ -259,10 +259,15 @@ void killsock (int sock)
    for (i = 0; i < MAXSOCKS; i++) {
       if (socklist[i].sock == sock) {
 	 close(socklist[i].sock);
-	 if (socklist[i].inbuf != NULL)
+	 if (socklist[i].inbuf != NULL) {
 	    nfree(socklist[i].inbuf);
-	 if (socklist[i].outbuf != NULL)
+		socklist[i].inbuf = NULL;
+	 }
+	 if (socklist[i].outbuf != NULL) {
 	    nfree(socklist[i].outbuf);
+		socklist[i].outbuf = NULL;
+		socklist[i].outbuflen = 0;
+	 }
 	 socklist[i].flags = SOCK_UNUSED;
 	 return;
       }
@@ -281,7 +286,7 @@ static int proxy_connect (int sock, char * host, int port, int proxy)
       /* numeric IP? */
       if ((host[strlen(host) - 1] >= '0') && (host[strlen(host) - 1] <= '9')) {
 	 IP ip = htonl((IP) inet_addr(host));
-	 my_memcpy(x, (char *)ip, 4);
+	 my_memcpy((char *)x, (char *)ip, 4);
       } else {
 	 /* no, must be host.domain */
 	 alarm(10);
