@@ -175,6 +175,7 @@ void rem_help_reference (char * file);
 void add_help_reference (char * file);
 void debug_help(int);
 void reload_help_data(void);
+void remove_gunk(char *);
 
 /* net.c */
 void my_memcpy (char *, char *, int);
@@ -235,5 +236,5 @@ void autolink_cycle (char *);
 void tell_file_stats (int, char *);
 void tell_user_ident (int,char *,int);
 void tell_users_match (int,char *,int,int,int,char *);
-int readuserfile (char *,struct userrec **,int);
+int readuserfile (char *,struct userrec **);
 #endif
