@@ -336,11 +336,11 @@ int write_user (struct userrec * u, FILE * f, int idx)
       cst = findchan(ch->channel);
       if (cst && ((idx < 0) || channel_shared(cst))) {
 	 if (idx >= 0) {
-	    fr.match = FR_CHAN;
+	    fr.match = (FR_CHAN | FR_BOT);
 	    get_user_flagrec(dcc[idx].user,&fr,ch->channel);
 	 } else
 	   fr.chan = BOT_SHARE;
-	 if (fr.chan & BOT_SHARE) {
+	 if ((fr.chan & BOT_SHARE) || (fr.bot & BOT_GLOBAL)) {
 	    fr.match = FR_CHAN;
 	    fr.chan = ch->flags;
 	    fr.udef_chan = ch->flags_udef;
